import mergeOverlappingRanges from './mergeOverlappingRanges';

import type {
    HighlightRange,
} from './types';


describe('mergeOverlappingRanges', () => {
    test('single range', () => {
        const ranges: HighlightRange[] = [
            [0, 1],
        ];

        const result = mergeOverlappingRanges(ranges);
        expect(result).toEqual(ranges);
    });

    test('non-overlapping ranges', () => {
        const ranges: HighlightRange[] = [
            [0, 1],
            [2, 3],
        ];

        const result = mergeOverlappingRanges(ranges);
        expect(result).toEqual(ranges);
    });

    test('continuous ranges', () => {
        const ranges: HighlightRange[] = [
            [0, 1],
            [1, 2],
        ];

        const result = mergeOverlappingRanges(ranges);
        expect(result).toEqual([
            [0, 2],
        ]);
    });

    test('partially overlapping ranges', () => {
        const ranges: HighlightRange[] = [
            [0, 2],
            [1, 3],
        ];

        const result = mergeOverlappingRanges(ranges);
        expect(result).toEqual([
            [0, 3],
        ]);
    });

    test('completely overlapping ranges', () => {
        const ranges: HighlightRange[] = [
            [0, 3],
            [1, 2],
        ];

        const result = mergeOverlappingRanges(ranges);
        expect(result).toEqual([
            [0, 3],
        ]);
    });
});
