import type {
    FoundationTableRowSearchFieldDefinitionParams,
} from '../types';

import toSearchField from './toSearchField';


interface TestType {
    test: string;
}

interface TestAdvancedSearchTerms {
    'filter_test': string;
}

test('matching value', () => {
    const definition: FoundationTableRowSearchFieldDefinitionParams<TestType> = {
        getValue(data: TestType) {
            return data.test;
        },
        key: 'test',
        title: 'Test',
    };

    const data = {
        test: 'cupcake ipsum',
    };

    const terms = ['cupcake'];
    const field = toSearchField(definition, data, terms);

    expect(field).toEqual({
        key: 'test',
        matchingTerms: ['cupcake'],
        title: 'Test',
        type: 'default',
        value: 'cupcake ipsum',
    });
});

test('matching value but advancedSearchOnly', () => {
    const definition: FoundationTableRowSearchFieldDefinitionParams<TestType> = {
        advancedSearchOnly: true,
        getValue(data: TestType) {
            return data.test;
        },
        key: 'test',
        title: 'Test',
    };

    const data = {
        test: 'cupcake ipsum',
    };

    const terms = ['cupcake'];
    const field = toSearchField(definition, data, terms);

    expect(field.matchingTerms).toHaveLength(0);
});

test('non matching value', () => {
    const definition: FoundationTableRowSearchFieldDefinitionParams<TestType> = {
        getValue(data: TestType) {
            return data.test;
        },
        key: 'test',
        title: 'Test',
    };

    const data = {
        test: 'cupcake ipsum',
    };

    const terms = ['dolor'];
    const field = toSearchField(definition, data, terms);

    expect(field.matchingTerms).toHaveLength(0);
});

test('matching advanced terms', () => {
    const terms = {
        'filter_test': 'cupcake',
    };

    const definition: FoundationTableRowSearchFieldDefinitionParams<TestType, TestAdvancedSearchTerms> = {
        getAdvancedSearchValue(terms) {
            return terms['filter_test'];
        },
        getValue(data: TestType) {
            return data.test;
        },
        key: 'test',
        title: 'Test',
    };

    const data = {
        'test': 'cupcake ipsum',
    };

    const field = toSearchField(definition, data, terms);

    expect(field).toEqual({
        key: 'test',
        matchingTerms: ['cupcake'],
        title: 'Test',
        type: 'default',
        value: 'cupcake ipsum',
    });
});

test('non matching advanced terms', () => {
    const terms = {
        'filter_test': 'dolor',
    };

    const definition: FoundationTableRowSearchFieldDefinitionParams<TestType, TestAdvancedSearchTerms> = {
        getAdvancedSearchValue(terms) {
            return terms['filter_test'];
        },
        getValue(data: TestType) {
            return data.test;
        },
        key: 'test',
        title: 'Test',
    };

    const data = {
        'test': 'cupcake ipsum',
    };

    const field = toSearchField(definition, data, terms);

    expect(field.matchingTerms).toHaveLength(0);
});
