import type React from 'react';
import type { FoundationLightboxButtonProps, FoundationLightboxComponentType } from '@billogram/foundation-lightbox';
import type { FoundationListDataProviderData, FoundationListDataProviderFetch, FoundationListDataProviderFetchInitialHandler, FoundationListDataProviderFetchMoreHandler, FoundationListDataProviderFetchSortHandler, FoundationListDataProviderRemoveItemHandler, FoundationListDataProviderResult, FoundationListDataProviderRowType, FoundationListDataProviderSortDirection, FoundationListDataProviderUpdateItemHandler } from '@billogram/foundation-list-data-provider';
import type { Money } from '@billogram/money';
import type { UseToggleResult } from '@billogram/use-toggle';
export interface FoundationTableRowPropsType<TRowData, TAdditionalRowData = never> {
    additionalData: TAdditionalRowData;
    data: TRowData;
}
export declare type FoundationTableRowComponentType<TRowData, TAdditionalRowData = never> = React.ComponentType<FoundationTableRowPropsType<TRowData, TAdditionalRowData>>;
export interface FoundationTableRowContextInternalType {
    columns: FoundationTableColumnDefinition[];
    expand: UseToggleResult;
    handle: UseToggleResult;
    highlight: UseToggleResult;
    transparency: UseToggleResult;
}
export interface FoundationTableRowContextInternalProviderProps {
    children: React.ReactNode;
    columns: FoundationTableColumnDefinition[];
    expand: UseToggleResult;
    handle: UseToggleResult;
    highlight: UseToggleResult;
    transparency: UseToggleResult;
}
export interface FoundationTableRowContextType<TRowData> {
    columns: FoundationTableColumnDefinition[];
    expand: UseExpandToggleResult;
    handle: UseToggleResult;
    highlight: UseToggleResult;
    refetchTable: FoundationListDataProviderFetchInitialHandler;
    remove: () => void;
    transparency: UseToggleResult;
    update: (item: TRowData) => void;
}
export interface FoundationTableRowProviderProps<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never> {
    additionalData?: TAdditionalRowData;
    columns: FoundationTableColumnDefinition[];
    fetchInitial: FoundationListDataProviderFetchInitialHandler;
    isFetching: boolean;
    isLast: boolean;
    isOdd: boolean;
    isSearchResult: boolean;
    item: FoundationListDataProviderRowType<TRowData>;
    removeItem: FoundationListDataProviderRemoveItemHandler<TRowData>;
    searchFields?: Array<FoundationTableRowSearchFieldDefinition<TRowData, TAdvancedSearchTerms>>;
    searchTerms: FoundationTableRowSearchTerms<TAdvancedSearchTerms>;
    TableRow: FoundationTableRowComponentType<TRowData, TAdditionalRowData>;
    TableRowExpand?: FoundationTableRowExpandComponentType<TRowData, TAdditionalRowData>;
    updateItem: FoundationListDataProviderUpdateItemHandler<TRowData>;
}
export interface FoundationTableRowConsumerProps<TRowData> {
    children: (context: FoundationTableRowContextType<TRowData>) => React.ReactElement | null;
}
export interface FoundationTableRowProviderCreateResult<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never> {
    FoundationTableRowProvider: React.ComponentType<FoundationTableRowProviderProps<TRowData, TAdditionalRowData, TAdvancedSearchTerms>>;
    FoundationTableRowConsumer: React.ComponentType<FoundationTableRowConsumerProps<TRowData>>;
    FoundationTableRowContext: React.Context<FoundationTableRowContextType<TRowData>>;
    useTableRow: () => FoundationTableRowContextType<TRowData>;
}
export interface FoundationTableRowErrorBoundaryProps {
    children: React.ReactNode;
    isSearchResult: boolean;
}
export interface FoundationTableRowErrorBoundaryState {
    didCatchError: boolean;
}
export declare type FoundationTableRowExpandComponentType<TRowData, TAdditionalRowData = never> = React.ComponentType<FoundationTableRowPropsType<TRowData, TAdditionalRowData>>;
export interface UseExpandToggleProps {
    initialAction?: string;
    initialExpanded?: boolean;
}
export interface UseExpandToggleResult {
    action: string;
    set: () => void;
    setWith: (action: string) => void;
    toggle: () => void;
    toggleWith: (action: string) => void;
    unset: () => void;
    value: boolean;
}
export interface FoundationTableColumnDefinition {
    hidden?: boolean;
    name: string;
    sortByColumnKey?: string;
    subTitle?: React.ReactNode;
    title?: React.ReactNode;
}
export interface FoundationTableSortHandler {
    (sortBy: string): void;
}
export interface FoundationSearchResultOverviewItem {
    count?: number;
    key: string;
    title: string;
    to: {
        pathname: string;
        query?: Record<string, string>;
    };
}
export declare type FoundationTableRowSearchFieldValue = Money | number | string;
export declare type FoundationTableRowSearchFieldDefinitionParamsFormattingFunction = (value: FoundationTableRowSearchFieldValue) => string;
export declare type FoundationTableRowSearchFieldDefinitionParamsType = FoundationTableRowSearchFieldDefinitionParamsFormattingFunction | 'date' | 'default' | 'money';
export interface FoundationTableRowSearchFieldDefinitionParams<TRowData, TAdvancedSearchTerms = never> {
    advancedSearchOnly?: boolean;
    getAdvancedSearchValue?: (terms: TAdvancedSearchTerms) => Array<string | undefined> | string | undefined;
    getValue: (data: TRowData) => FoundationTableRowSearchFieldValue | null | undefined;
    key: string;
    title: React.ReactNode;
    type?: FoundationTableRowSearchFieldDefinitionParamsType;
}
export interface FoundationTableRowSearchField {
    key: string;
    matchingTerms: string[];
    title: React.ReactNode;
    type: FoundationTableRowSearchFieldDefinitionParamsType;
    value: FoundationTableRowSearchFieldValue;
}
export declare type FoundationTableRowSearchGeneralTerms = string[];
export declare type FoundationTableRowSearchAdvancedTerms<K extends string> = Partial<Record<K, string>>;
export declare type FoundationTableRowSearchTerms<TAdvancedSearchTerms extends FoundationTableRowSearchAdvancedTerms<Extract<keyof TAdvancedSearchTerms, string>> = never> = FoundationTableRowSearchGeneralTerms | TAdvancedSearchTerms;
export interface FoundationTableRowSearchFieldDefinition<TRowData, TAdvancedSearchTerms = never> {
    (data: TRowData, terms: FoundationTableRowSearchTerms<TAdvancedSearchTerms>): React.ReactNode;
}
export interface FoundationTableMenuItemAction {
    disabled?: boolean;
    onClick: () => void;
    text: string;
    type: 'action';
    value: string;
}
export interface FoundationTableMenuItemLightbox {
    disabled?: boolean;
    Lightbox: FoundationLightboxComponentType;
    text: string;
    type: 'lightbox';
    value: string;
}
export interface FoundationTableMenuItemLink {
    disabled?: boolean;
    href: string;
    text: string;
    type: 'link';
    value: string;
}
export interface FoundationTableMenuItemRoute {
    disabled?: boolean;
    text: string;
    to: string;
    type: 'route';
    value: string;
}
export declare type FoundationTableMenuItem = FoundationTableMenuItemAction | FoundationTableMenuItemLightbox | FoundationTableMenuItemLink | FoundationTableMenuItemRoute;
export interface FoundationTablePropsType<TFilter extends string, TAdvancedSearchTerms = never> {
    filter?: TFilter;
    isSearchResult?: boolean;
    searchTerms?: FoundationTableRowSearchGeneralTerms | TAdvancedSearchTerms;
    searchQuery?: Record<string, string | string[]>;
}
export interface FoundationTableProps<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never> {
    additionalRowData?: TAdditionalRowData;
    columns?: FoundationTableColumnDefinition[];
    EmptyState?: React.ComponentType<{}>;
    fetchInitial?: FoundationListDataProviderFetchInitialHandler;
    fetchMore?: FoundationListDataProviderFetchMoreHandler;
    fetchSort?: FoundationListDataProviderFetchSortHandler;
    isSearchResult?: boolean;
    removeItem?: FoundationListDataProviderRemoveItemHandler<TRowData>;
    searchFields?: Array<FoundationTableRowSearchFieldDefinition<TRowData, TAdvancedSearchTerms>>;
    searchTerms?: FoundationTableRowSearchTerms<TAdvancedSearchTerms>;
    subTitle?: React.ReactNode;
    table: FoundationListDataProviderResult<TRowData>;
    tableName?: string;
    TableRow?: FoundationTableRowComponentType<TRowData, TAdditionalRowData>;
    TableRowExpand?: FoundationTableRowExpandComponentType<TRowData, TAdditionalRowData>;
    title?: React.ReactNode;
    titleFilter?: React.ReactNode;
    updateItem?: FoundationListDataProviderUpdateItemHandler<TRowData>;
}
export declare type FoundationTableCreateResult<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never> = Omit<FoundationTableRowProviderCreateResult<TRowData, TAdditionalRowData, TAdvancedSearchTerms>, 'FoundationTableRowProvider'> & {
    FoundationTable: React.ComponentType<FoundationTableProps<TRowData, TAdditionalRowData, TAdvancedSearchTerms>>;
};
export interface FoundationTableCaptionProps {
    subTitle: React.ReactNode;
    title: React.ReactNode;
}
export declare type FoundationTableDataConsumerProps<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never> = Pick<FoundationTableProps<TRowData, TAdditionalRowData, TAdvancedSearchTerms>, 'additionalRowData' | 'columns' | 'EmptyState' | 'isSearchResult' | 'searchFields' | 'searchTerms' | 'subTitle' | 'tableName' | 'TableRow' | 'TableRowExpand' | 'title' | 'titleFilter'>;
export interface FoundationTableDataProviderProps<TRowData, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>, TOptions = never> {
    children?: React.ReactNode;
    fetchData: FoundationListDataProviderFetch<TRowData, TData>;
    initialFetchDataOptions?: TOptions;
    initialLimit?: number;
    initialSortBy?: string;
    initialSortDirection?: FoundationListDataProviderSortDirection;
}
export declare type FoundationTableDataProsumerProps<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>, TOptions = never> = Omit<FoundationTableDataProviderProps<TRowData, TData, TOptions>, 'children'> & FoundationTableDataConsumerProps<TRowData, TAdditionalRowData, TAdvancedSearchTerms>;
export declare type FoundationTableDataProviderCreateResult<TRowData, TAdditionalRowData = never, TAdvancedSearchTerms = never, TData extends FoundationListDataProviderData<TRowData> = FoundationListDataProviderData<TRowData>> = Omit<FoundationTableCreateResult<TRowData, TAdditionalRowData, TAdvancedSearchTerms>, 'FoundationTable'> & {
    FoundationTableDataConsumer: React.ComponentType<FoundationTableDataConsumerProps<TRowData, TAdditionalRowData, TAdvancedSearchTerms>>;
    FoundationTableDataProsumer: React.ComponentType<FoundationTableDataProsumerProps<TRowData, TAdditionalRowData, TAdvancedSearchTerms, TData>>;
    FoundationTableDataProvider: React.ComponentType<FoundationTableDataProviderProps<TRowData, TData>>;
};
export interface FoundationTableFetchMoreButtonsProps {
    fetchMore: (limit: number) => void;
    isFetching: boolean;
    itemsLeftToFetch: number;
}
export interface FoundationTableStateProps {
    children?: React.ReactNode;
    description?: React.ReactNode;
    title: React.ReactNode;
    ui?: 'empty' | 'error';
}
export interface FoundationTableRowExpandResultProps {
    children: React.ReactNode;
    errorMessage?: React.ReactNode;
    hasFetchError?: boolean;
    isFetching?: boolean;
    title?: React.ReactNode;
}
export interface FoundationTableRowExpandResultGroupProps {
    children: React.ReactNode;
    errorMessage?: React.ReactNode;
    hasFetchError?: boolean;
    isFetching?: boolean;
}
export interface FoundationTableRowExpandResultGroupSectionProps {
    children: React.ReactNode;
}
export interface FoundationTableRowExpandResultPropertyProps {
    children: React.ReactNode;
    highlight?: boolean;
    title: React.ReactNode;
}
export interface FoundationTableRowExpandResultPropertyGroupProps {
    children?: React.ReactNode;
}
export interface FoundationTableRowExpandResultPropertyGroupSectionProps {
    children: React.ReactNode;
}
export interface FoundationTableHeaderProps {
    columns: FoundationTableColumnDefinition[];
    currentSortBy: string;
    currentSortDirection: FoundationListDataProviderSortDirection;
    isFetching: boolean;
    shouldDisableSorting: boolean;
    sort: FoundationTableSortHandler;
}
export interface FoundationTableHeaderCellProps {
    children?: React.ReactNode;
    columnName: string;
    currentSortBy: string;
    currentSortDirection: FoundationListDataProviderSortDirection;
    hidden?: boolean;
    isFetching: boolean;
    shouldDisableSorting: boolean;
    sort: FoundationTableSortHandler;
    sortByColumnKey?: string;
}
export interface FoundationTableHeaderRowProps {
    children: React.ReactNode;
}
export interface FoundationTableCellProps {
    canExpand?: boolean;
    children: React.ReactNode;
    columnName: string;
}
export interface FoundationTableCellAsyncButtonProps<T, U> {
    asyncAction: () => Promise<T>;
    children: React.ReactNode;
    columnName: string;
    onAsyncActionSuccess?: (data: T) => void;
    onAsyncActionError?: (e: U) => void;
    visible?: boolean;
}
export interface FoundationTableCellDualValueProps {
    canExpand?: boolean;
    columnName: string;
    subValue?: React.ReactNode;
    ui?: FoundationTableCellValueUI[];
    value: React.ReactNode;
}
export interface FoundationTableCellExpandButtonProps {
    columnName: string;
}
export declare type FoundationTableCellColor = 'black' | 'blue' | 'brown' | 'gray' | 'green' | 'orange' | 'pink' | 'purple' | 'red' | 'yellow';
export declare type FoundationTableCellIconColor = FoundationTableCellColor;
export declare type FoundationTableCellIconType = 'check' | 'circle' | 'cross' | 'donut' | 'user' | 'warning' | false;
export interface FoundationTableCellIconProps {
    color?: FoundationTableCellIconColor;
    columnName: string;
    type?: FoundationTableCellIconType;
    tooltip?: React.ReactNode;
}
export declare type FoundationTableCellLightboxButtonProps = FoundationLightboxButtonProps & {
    columnName: string;
};
export interface FoundationTableCellLinkButtonProps {
    columnName: string;
    href: string;
    ui: 'download';
}
export interface FoundationTableCellMainValueProps {
    children: React.ReactNode;
    columnName: string;
    to: string;
}
export interface FoundationTableCellMenuProps {
    columnName: string;
    options: FoundationTableMenuItem[];
}
export interface FoundationTableCellRouteButtonProps {
    columnName: string;
    to: string;
    ui: 'edit' | 'view';
}
export interface FoundationTableCellSingleControlGroupProps {
    children?: React.ReactNode;
}
export interface FoundationTableCellValueProps {
    canExpand?: boolean;
    children: React.ReactNode;
    columnName: string;
    ui?: FoundationTableCellValueUI[];
}
export declare type FoundationTableCellValueUI = 'bold' | 'medium' | FoundationTableCellColor;
export interface FoundationTableRowProps {
    children: React.ReactNode;
}
export interface FoundationTableRowSearchResultProps {
    children: React.ReactNode;
    title: React.ReactNode;
}
export interface FoundationTableRowSearchResultGroupProps<TRowData, TAdvancedSearchTerms> {
    data: TRowData;
    fields: Array<FoundationTableRowSearchFieldDefinition<TRowData, TAdvancedSearchTerms>>;
    terms: FoundationTableRowSearchTerms<TAdvancedSearchTerms>;
}
export interface FoundationSearchResultOverviewProps {
    isFetching?: boolean;
    items?: FoundationSearchResultOverviewItem[];
}
